unit Prop;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, WMPLib_TLB, ComCtrls;

type
  TPropForm = class(TForm)
    PageControl1: TPageControl;
    TabSheet1: TTabSheet;
    TabSheet2: TTabSheet;
    TabSheet3: TTabSheet;
    MemSettings: TMemo;
    MemMedia: TMemo;
    MemControls: TMemo;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    procedure ShowSettingsInfo();
    procedure ShowMediaInfo();
    procedure ShowControlsInfo();
  public

  end;

var
    PropForm: TPropForm;

const
    //  PlayerPlayStateChange
    PLAY_STATE_STR: array[0..10] of string = (
        'Undefined',
        'Stopped',
        'Paused',
        'Playing',
        'ScanForward',
        'ScanReverse',
        'Buffering',
        'Waiting',
        'MediaEnded',
        'Transitioning',
        'Ready'
        );

    //  PlayerOpenStateChange
    OPEN_STATE_STR: array[0..21] of string = (
        'Undefined',
        'PlaylistChanging',
        'PlaylistLocating',
        'PlaylistConnecting',
        'PlaylistLoading',
        'PlaylistOpening',
        'PlaylistOpenNoMedia',
        'PlaylistChanged',
        'MediaChanging',
        'MediaLocating',
        'MediaConnecting',
        'MediaLoading',
        'MediaOpening',
        'MediaOpen',
        'BeginCodecAcquisition',
        'EndCodecAcquisition',
        'BeginLicenseAcquisition',
        'EndLicenseAcquisition',
        'BeginIndividualization',
        'EndIndividualization',
        'MediaWaiting',
        'OpeningUnknownURL'
        );

implementation

uses
    Main;

{$R *.dfm}

//-----------------------------------------------------------------------------
procedure TPropForm.FormCreate(Sender: TObject);
begin
    //  
end;

//-----------------------------------------------------------------------------
procedure TPropForm.FormShow(Sender: TObject);
begin
    ShowSettingsInfo();
    ShowMediaInfo();
    ShowControlsInfo();
end;

//-----------------------------------------------------------------------------
//  ON/OFF\pz
const
    ON_OFF: array[Boolean] of string = ('OFF', 'ON');
    OK_NG: array[Boolean] of string = ('NG', 'OK');

//-----------------------------------------------------------------------------
//  vC[Ɋւ
procedure TPropForm.ShowSettingsInfo();
var
    LPlayer: TWindowsMediaPlayer;
    LSettings: IWMPSettings;
    LInt: Integer;
    LDbl: Double;
    LBln: Boolean;
    LStr: String;
    LLine: String;
begin
    MemSettings.Lines.BeginUpdate();
    MemSettings.Clear();

    LPlayer := MainForm.FPlayer;
    LSettings := LPlayer.settings;

    //  o[W
    LStr := LPlayer.versionInfo;
    LLine := Format('%s.versionInfo'#9'%s', [LPlayer.ClassName, LStr]);
    MemSettings.Lines.Add(LLine);

    //  Đ
    LBln := LSettings.autoStart;
    LLine := Format('IWMPSettings.autoStart'#9'%s', [ON_OFF[LBln]]);
    MemSettings.Lines.Add(LLine);

    //  oX
    LInt := LSettings.balance;
    LLine := Format('IWMPSettings.balance(-100..100)'#9'%d', [LInt]);
    MemSettings.Lines.Add(LLine);

    //  baseURL
    LStr := LSettings.baseURL;
    LLine := Format('IWMPSettings.baseURL'#9'%s', [LStr]);
    MemSettings.Lines.Add(LLine);

    //  defaultFrame
    LStr := LSettings.defaultFrame;
    LLine := Format('IWMPSettings.defaultFrame'#9'%s', [LStr]);
    MemSettings.Lines.Add(LLine);

    //  G[_CAO
    LBln := LSettings.enableErrorDialogs;
    LLine := Format('IWMPSettings.enableErrorDialogs'#9'%s', [ON_OFF[LBln]]);
    MemSettings.Lines.Add(LLine);

    //  invokeURLs
    LBln := LSettings.invokeURLs;
    LLine := Format('IWMPSettings.invokeURLs'#9'%s', [ON_OFF[LBln]]);
    MemSettings.Lines.Add(LLine);

    //  ~[g
    LBln := LSettings.mute;
    LLine := Format('IWMPSettings.mute'#9'%s', [ON_OFF[LBln]]);
    MemSettings.Lines.Add(LLine);

    //  Đ
    LInt := LSettings.playCount;
    LLine := Format('IWMPSettings.playCount'#9'%d', [LInt]);
    MemSettings.Lines.Add(LLine);

    //  Đx
    LDbl := LSettings.rate;
    LLine := Format('IWMPSettings.rate'#9'%f', [LDbl]);
    MemSettings.Lines.Add(LLine);

    //  ĐxύX
    LBln := LSettings.isAvailable['Rate'];
    LLine := Format('IWMPSettings.isAvailable[''Rate'']'#9'%s', [OK_NG[LBln]]);
    MemSettings.Lines.Add(LLine);

    //  
    LInt := LSettings.volume;
    LLine := Format('IWMPSettings.volume'#9'%d', [LInt]);
    MemSettings.Lines.Add(LLine);

    //  [v[h
    LBln := LSettings.getMode('loop');
    LLine := Format('IWMPSettings.getMode(''loop'')'#9'%s', [ON_OFF[LBln]]);
    MemSettings.Lines.Add(LLine);

    //  Vbt[h
    LBln := LSettings.getMode('shuffle');
    LLine := Format('IWMPSettings.getMode(''shuffle'')'#9'%s', [ON_OFF[LBln]]);
    MemSettings.Lines.Add(LLine);

    MemSettings.Lines.EndUpdate();
end;

//-----------------------------------------------------------------------------
//  fBAɊւ
procedure TPropForm.ShowMediaInfo();
var
    LPlayer: TWindowsMediaPlayer;
    LMedia: IWMPMedia;
    LInt: Integer;
    LStr: String;
    LStr2: String;
    LLine: String;
    i: Integer;
begin
    MemMedia.Lines.BeginUpdate();
    MemMedia.Clear();

    LPlayer := MainForm.FPlayer;
    LMedia := LPlayer.currentMedia;

    if (LMedia = nil) then
    begin
        LLine := 'No Media';
        MemMedia.Lines.Add(LLine);
    end
    else
    begin
        //  
        LInt := LMedia.imageSourceWidth;
        LLine := Format('IWMPMedia.imageSourceWidth'#9'%d', [LInt]);
        MemMedia.Lines.Add(LLine);

        //  
        LInt := LMedia.imageSourceHeight;
        LLine := Format('IWMPMedia.imageSourceHeight'#9'%d', [LInt]);
        MemMedia.Lines.Add(LLine);

        //  fBA^Cg
        LStr := LMedia.name;
        LLine := Format('IWMPMedia.name'#9'%s', [LStr]);
        MemMedia.Lines.Add(LLine);

        //  fBAURL
        LStr := LMedia.sourceURL;
        LLine := Format('IWMPMedia.sourceURL'#9'%s', [LStr]);
        MemMedia.Lines.Add(LLine);

        //  񋓌n
        for i := 0 to LMedia.attributeCount - 1 do
        begin
            LStr := LMedia.getAttributeName(i);
            LStr2 := LMedia.getItemInfo(LStr);
            LLine := Format('IWMPMedia.%s'#9'%s', [LStr, LStr2]);
            MemMedia.Lines.Add(LLine);
        end;
    end;

    MemMedia.Lines.EndUpdate();
end;

//-----------------------------------------------------------------------------
//  Rg[Ɋւ
procedure TPropForm.ShowControlsInfo();
var
    LPlayer: TWindowsMediaPlayer;
    LControls: IWMPControls;
    LBln: Boolean;
    LLine: String;
begin
    MemControls.Lines.BeginUpdate();
    MemControls.Clear();

    LPlayer := MainForm.FPlayer;
    LControls := LPlayer.controls;

    //  Đł邩
    LBln := LControls.isAvailable['Play'];
    LLine := Format('IWMPControls.isAvailable[''Play'']'#9'%s', [OK_NG[LBln]]);
    MemControls.Lines.Add(LLine);

    //  ꎞ~ł邩
    LBln := LControls.isAvailable['Pause'];
    LLine := Format('IWMPControls.isAvailable[''Pause'']'#9'%s', [OK_NG[LBln]]);
    MemControls.Lines.Add(LLine);

    //  ~ł邩
    LBln := LControls.isAvailable['Stop'];
    LLine := Format('IWMPControls.isAvailable[''Stop'']'#9'%s', [OK_NG[LBln]]);
    MemControls.Lines.Add(LLine);

    //  (rate = 5)Đł邩
    LBln := LControls.isAvailable['FastForward'];
    LLine := Format('IWMPControls.isAvailable[''FastForward'']'#9'%s', [OK_NG[LBln]]);
    MemControls.Lines.Add(LLine);

    //  ߂(rate = 5)Đł邩
    LBln := LControls.isAvailable['FastReverse'];
    LLine := Format('IWMPControls.isAvailable[''FastReverse'']'#9'%s', [OK_NG[LBln]]);
    MemControls.Lines.Add(LLine);

    //  vCXg̎̃fBAɂ邩
    LBln := LControls.isAvailable['Next'];
    LLine := Format('IWMPControls.isAvailable[''Next'']'#9'%s', [OK_NG[LBln]]);
    MemControls.Lines.Add(LLine);

    //  vCXg̑ÕfBAɂ邩
    LBln := LControls.isAvailable['Previous'];
    LLine := Format('IWMPControls.isAvailable[''Previous'']'#9'%s', [OK_NG[LBln]]);
    MemControls.Lines.Add(LLine);

    //  ݈ʒuύXł邩
    LBln := LControls.isAvailable['CurrentPosition'];
    LLine := Format('IWMPControls.isAvailable[''CurrentPosition'']'#9'%s', [OK_NG[LBln]]);
    MemControls.Lines.Add(LLine);

    MemControls.Lines.EndUpdate();
end;

end.
